@@ -2739,3 +2739,28 @@ def test_string_comparison():
     a = 1 * cm
     assert not (a == "hello")
     assert a != "hello"
+
+
+def test_int8_comparison():
+    # see regression https://github.com/yt-project/unyt/issues/369
+    a = unyt_array(np.zeros(5, dtype=np.int8))
+    assert all(e == 0 for e in a)
+
+
+def test_setitem():
+    # see https://github.com/yt-project/unyt/issues/373
+    a = [1, 2, 3] * cm
+    a[1] = 2 * m
+    assert a[1].value == 200
+    assert a[1].units == cm
+
+    with pytest.raises(UnitConversionError):
+        a[1] = 2 * g
+
+    a[1] = 2
+    assert a[1].value == 2
+    assert a[1].units == cm
+
+    a[1] = unyt_quantity(2)
+    assert a[1].value == 2
+    assert a[1].units == cm
